"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
class JsQRScanner {
    constructor(scannerProvider) {
        this.scanner = scannerProvider.createScanner(s => this.handleScannedText(s));
    }
    handleScannedText(scannedText) {
        if (this.onQRCodeScanned) {
            this.onQRCodeScanned(scannedText);
        }
    }
    appendTo(htmlElement) {
        this.scanner.appendTo(htmlElement);
    }
    removeFrom(htmlElement) {
        this.scanner.removeFrom(htmlElement);
    }
    stopScanning() {
        this.scanner.stopScanning();
    }
    resumeScanning() {
        this.scanner.resumeScanning();
    }
    getScanInterval() {
        return this.scanner.getScanInterval();
    }
    setScanInterval(scanInterval) {
        this.scanner.setScanInterval(scanInterval);
    }
    getSnapImageMaxSize() {
        return this.scanner.getSnapImageMaxSize();
    }
    setSnapImageMaxSize(snapImageMaxSize) {
        this.scanner.setSnapImageMaxSize(snapImageMaxSize);
    }
    isActive() {
        return this.scanner.isActive();
    }
    isScanning() {
        return this.scanner.isScanning();
    }
    static create(path_to_jsqrscanner_js) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!g.JsQRScanner) {
                loadScript(path_to_jsqrscanner_js);
            }
            return new Promise((resolve, reject) => {
                CallWhenQRSacannerReady(sp => {
                    const scanner = new JsQRScanner(sp);
                    resolve(scanner);
                });
            });
        });
    }
}
exports.JsQRScanner = JsQRScanner;
function loadScript(path) {
    if (!hasScriptElement(path) && document) {
        const script = document.createElement('script');
        script.setAttribute('src', path);
        if (document.head) {
            document.head.appendChild(script);
        }
    }
}
function hasScriptElement(path) {
    if (document) {
        const scriptTags = document.getElementsByTagName('script');
        // tslint:disable-next-line:prefer-for-of
        for (let i = 0; i < scriptTags.length; ++i) {
            if (scriptTags[i].src.indexOf(path) !== -1) {
                return true;
            }
        }
    }
    return false;
}
class ScannerProvider {
    createScanner(onQRCodeScanned) {
        if (!g.JsQRScanner) {
            throw new Error('JsQRScanner is not ready yet!');
        }
        return new g.JsQRScanner(onQRCodeScanned);
    }
}
const g = window;
const callbacks = [];
let scannerProvider;
function CallWhenQRSacannerReady(cb) {
    if (scannerProvider) {
        cb(scannerProvider);
    }
    else {
        callbacks.push(cb);
    }
}
function JsQRScannerReady() {
    scannerProvider = new ScannerProvider();
    if (callbacks.length > 0) {
        const provider = scannerProvider;
        callbacks.forEach(cb => cb(provider));
        callbacks.splice(0, callbacks.length);
    }
}
g.JsQRScannerReady = JsQRScannerReady;
//# sourceMappingURL=index.js.map